CindelFlutterLibsWeb class
Web plugin registration for the Cindel runtime assets package.
The Cindel public API lives in package:cindel/cindel.dart. This plugin
exists so Flutter Web includes the packaged Worker, JavaScript glue, and
Wasm runtime assets from cindel_flutter_libs.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void - Registers the Web companion package with Flutter.